import 'package:flutter/material.dart';

class DrawerItem extends StatelessWidget {

  final IconData? icon;
  final String? text;
  final Color? splashColor;
  final Color normalForegroundColor;
  final Color? checkedForegroundColor;
  final Color checkedBackgroundColor;
  final Decoration? backgroundDecoration;
  final ShapeBorder selectCustomBorder;
  final bool checked;
  final GestureTapCallback? onTap;
  final EdgeInsetsGeometry padding;
  final FontWeight fontWeight;
  final double fontSize;

  DrawerItem({
    this.icon,
    this.text,
    this.splashColor,
    this.normalForegroundColor = const Color(0xff414141),
    this.checkedForegroundColor,
    this.checkedBackgroundColor = const Color(0x779e9e9e),
    this.backgroundDecoration,
    this.selectCustomBorder = const RoundedRectangleBorder(
        borderRadius: BorderRadius.only(
          topRight: Radius.circular(100),
          bottomRight: Radius.circular(100),)),
    this.checked = false,
    this.onTap,
    this.padding = const EdgeInsets.all(16),
    this.fontWeight = FontWeight.normal,
    this.fontSize = 14.0,
  });

  bool get isChecked => checked;

  Color get _getCheckedForegroundColor =>
      checkedForegroundColor ?? normalForegroundColor;

  Decoration get _getBackgroundDecoration =>
      backgroundDecoration ?? BoxDecoration(
          color: checkedBackgroundColor, borderRadius: BorderRadius.only(
        topRight: Radius.circular(100), bottomRight: Radius.circular(100),));

  ShapeBorder get _getSelectCustomBorder => selectCustomBorder;

  @override
  Widget build(BuildContext context) =>
      Container(
        decoration: isChecked ? _getBackgroundDecoration : null,
        margin: EdgeInsets.only(right: 8),
        child: InkWell(
          highlightColor: splashColor,
          splashColor: splashColor,
          customBorder: _getSelectCustomBorder,
          onTap: onTap,
          child: Padding(
            padding: padding,
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: <Widget>[
                if(icon != null)
                  Icon(icon, color: isChecked
                      ? _getCheckedForegroundColor
                      : normalForegroundColor,),
                if(icon != null) VerticalDivider(width: 24,),
                Expanded(
                  child: Text(text!,
                    overflow: TextOverflow.ellipsis,
                    style: TextStyle(
                      color: isChecked
                          ? _getCheckedForegroundColor
                          : normalForegroundColor,
                      fontWeight: fontWeight,
                      fontSize: fontSize,
                    ),
                  ),
                ),
              ],
            ),
          ),
        ),
      );
}