import 'package:flutter/material.dart';

class HintView extends StatelessWidget{
  final String text;
  final Color? textColor;
  final double textSize;
  final IconData iconData;
  final Color? iconDataColor;
  final double iconDataSize;
  final Widget? textView;
  final Icon? iconView;
  final Image? imageView;
  final EdgeInsets padding;
  final double dividerHeight;
  final double? width;
  final double? height;

  HintView({
    this.text = 'No data to show',
    this.textColor,
    this.textSize = 22,
    this.iconData = Icons.sentiment_dissatisfied,
    this.iconDataColor,
    this.iconDataSize = 96,
    this.textView,
    this.iconView,
    this.imageView,
    this.padding = const EdgeInsets.all(16),
    this.dividerHeight = 16,
    this.width,
    this.height,
  });

  @override
  Widget build(BuildContext context) {
    return Container(
      width: width,
      height: height,
      alignment: Alignment.center,
      padding: padding,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.center,
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          _getIcon(context),
          SizedBox(height: dividerHeight,),
          _getText(context),
        ],
      ),
    );
  }

  Widget _getIcon(BuildContext context){
    if(iconView != null) return iconView!;
    if(imageView != null) return imageView!;
    final iconDataColor = this.iconDataColor ?? Theme.of(context).textTheme.headline4?.color;
    return Icon(iconData, size: iconDataSize, color: iconDataColor,);
  }

  Widget _getText(BuildContext context){
    if(textView != null) return textView!;
    final textColor = this.textColor ?? Theme.of(context).textTheme.headline4?.color;
    return Center(
        child: Text(text, style: TextStyle(color: textColor, fontSize: textSize), textAlign: TextAlign.center,)
    );
  }

}